@@ -1,5 +1,6 @@
 from typing import List, Dict, Tuple
 from .client import FinClient
+from .findata_client import FinDataClient
 from .data.login_data import LoginData
 from .data.market.ohlc_data import OHLCData
 from .data.chart.chart_init_param_data import ChartInitParamData
@@ -16,6 +17,7 @@ from .data.market.query_param_data import QueryParamData
 from .data.market.sub_ohlc_param_data import SubOHLCParamData
 from .data.market.history_ohlc_param_data import HistoryOHLCParamData
 from .data.market.fin_persist_read_param_data import FinPersistReadParamData
+from .data.market.fin_persist_delete_param_data import FinPersistDeleteParamData
 from .data.trade.trade_param_data import TradeParamData
 from .data.trade.read_history_order_param_data import ReadHistoryOrderParamData
 from .data.trade.read_history_tradeorder_param_data import ReadHistoryTradeOrderParamData
@@ -24,6 +26,8 @@ from .data.trade.get_orders_param_data import GetOrdersParamData
 from .data.trade.get_tradeorders_param_data import GetTradeOrdersParamData
 from .data.trade.get_positions_param_data import GetPositionsParamData
 from .data.trade.read_exc_product_param_data import ReadExcProductParamData
+from .data.trade.read_instrument_param_data import ReadInstrumentParamData
+from .data.trade.save_instrument_param_data import SaveInstrumentParamData
 
 
 def conncet(host: str = None, port: int = None, ):
@@ -42,6 +46,22 @@ def close():
     FinClient.instance().close()
 
 
+def findata_conncet(host: str = None, port: int = None, ):
+    return FinDataClient.instance().connect(host, port)
+
+
+def findata_is_connected():
+    return FinDataClient.instance().is_connected()
+
+
+def findata_login(user_id: str = '', password: str = ''):
+    return FinDataClient.instance().base_handle().login(LoginData(user_id, password))
+
+
+def findata_close():
+    FinDataClient.instance().close()
+
+
 def set_callback(**kwargs):
     '''
     设置行情回调
@@ -65,6 +85,21 @@ def set_auth_params(userid, password, host: str = None, port: int = None):
     return login(userid, password)
 
 
+def set_findata_auth_params(userid, password, host: str = None, port: int = None):
+    '''
+    设置登录信息
+    :param userid:用户名
+    :param password:密码
+    :param host:网络地址默认为None
+    :param port:端口号默认为None
+    :return:result msg
+    '''
+    ret = findata_conncet(host, port)
+    if ret is None or ret[0] is False:
+        return ret
+    return findata_login(userid, password)
+
+
 def set_chart_init_params(params: ChartInitParamData):
     return FinClient.instance().chart_handle().set_chart_init_params(params)
 
@@ -327,52 +362,102 @@ def get_history_ohlc(market_name: str, exchang_id: str, instrument_id: str, rang
 
 
 def get_ohlc_column_types():
-    return FinClient.instance().market_handle().get_ohlc_column_types()
+    return FinDataClient.instance().findata_handle().get_ohlc_column_types()
 
 
 def get_tick_column_types():
-    return FinClient.instance().market_handle().get_tick_column_types()
+    return FinDataClient.instance().findata_handle().get_tick_column_types()
 
 
-def fin_save_ohlc_list(instrument_id: str, range: str, df, **kwargs):
-    """批量按天保存OHLC数据
+def get_day_column_types():
+    return FinDataClient.instance().findata_handle().get_day_column_types()
+
+
+def get_instrument_column_types():
+    return FinDataClient.instance().findata_handle().get_instrument_columns_types()
+
+
+def get_db_column_types():
+    return FinDataClient.instance().findata_handle().get_db_columns_types()
+
+
+def fin_save_day_list(instrument_id: str, df, period: str = 'day', **kwargs):
+    """批量按天保存day数据
 
     Args:
         instrument_id (str, optional) 合约编码 Defaults  to ''.
-        range (str, optional) 周期 Defaults  to ''
         df (DataFrame, optional): 数据集 Defaults to
         列及类型
-        ['ExchangeID':str, 'InstrumentID':str, 'TradingDay':str, 'TradingTime':str, 'StartTime':str,
-        'EndTime':str, 'ActionDay':str, 'ActionTimeSpan':int, 'Range':int, 'Index':int,
-        'OpenPrice':float, 'HighestPrice':float, 'LowestPrice':float, 'ClosePrice':float,
-        'TotalTurnover':float, 'TotalVolume':int, 'OpenInterest':float, 'PreSettlementPrice':float,
-        'OpenBidPrice':float, 'OpenAskPrice':float, 'OpenBidVolume':int, 'OpenAskVolume':int,
-        'HighestBidPrice':float, 'HighestAskPrice':float, 'HighestBidVolume':int, 'HighestAskVolume':int,
-        'LowestBidPrice':float, 'LowestAskPrice':float, 'LowestBidVolume':int, 'LowestAskVolume':int,
-        'CloseBidPrice':float, 'CloseAskPrice':float, 'CloseBidVolume':int, 'CloseAskVolume':int].
+        "ExchangeID": str, "InstrumentID": str, "TradingDay": str,
+        "OpenPrice": np.float32, "HighestPrice": np.float32, "LowestPrice": np.float32, "ClosePrice": np.float32,
+        "UpperLimitPrice": np.float32, "LowerLimitPrice": np.float32,
+        "PreClosePrice": np.float32, "PreSettlementPrice": np.float32, "PreOpenInterest": np.int32
+        period (str, optional) 周期 Defaults  to 'day'
         compress (str, optional): 压缩方式 Defaults to 'zip'.
         level 压缩等级 Defaults to -1
         pack 序列化方式 msgpack pickle Defaults to 'msgpack'.
         vacuum 是否直接整理数据文件 Defaults to True.
+        base_path 默认存取目录
     Returns:
         _type_: [bool,str]
     """
 
-    return FinClient.instance().market_handle().fin_save_ohlc_list(instrument_id=instrument_id, range=range, df=df, kwargs=kwargs)
+    return FinDataClient.instance().findata_handle().fin_save_day_list(instrument_id, df, period, **kwargs)
 
 
-def fin_read_ohlc_list(instrument_id: str, range: str, start_date: int, end_date: int, base_path: str = '', is_return_list: bool = False):
+def fin_read_day_list(instrument_id: str, start_date: int = 0, end_date: int = 99999999, period: str = 'day', **kwargs):
+    '''
+    获取day数据
+    :param instrument_id:合约编码
+    :param start_date 开始日期
+    :param end_date 结束日期
+    :param period:周期
+    :param base_path 默认存取目录
+    :return:result,msg
+    '''
+    base_path = '' if 'base_path' not in kwargs.keys()else kwargs.get('base_path')
+    return FinDataClient.instance().findata_handle().fin_read_day_list(FinPersistReadParamData(
+        instrument_id=instrument_id, period=period, start_date=start_date, end_date=end_date, base_path=base_path))
+
+
+def fin_save_ohlc_list(instrument_id: str, df, period: str, **kwargs):
+    """批量按天保存OHLC数据
+
+    Args:
+        instrument_id (str, optional) 合约编码 Defaults  to ''.
+        df (DataFrame, optional): 数据集 Defaults to
+        列及类型
+        "ExchangeID": str, "InstrumentID": str, "TradingDay": str, "ActionDay": str, "ActionTime": str,
+        "Period": np.int32, "OpenPrice": np.float32, "HighestPrice": np.float32, "LowestPrice": np.float32,
+        "ClosePrice": np.float32, "CloseVolume": np.int32, "CloseBidPrice": np.float32,
+        "CloseAskPrice": np.float32, "CloseBidVolume": np.int32, "CloseAskVolume": np.int32,
+        "TotalTurnover": np.float64, "TotalVolume": np.int32, "OpenInterest": np.int32
+        period (str, optional) 周期 Defaults  to ''
+        compress (str, optional): 压缩方式 Defaults to 'zip'.
+        level 压缩等级 Defaults to -1
+        pack 序列化方式 msgpack pickle Defaults to 'msgpack'.
+        vacuum 是否直接整理数据文件 Defaults to True.
+        base_path 默认存取目录
+    Returns:
+        _type_: [bool,str]
+    """
+
+    return FinDataClient.instance().findata_handle().fin_save_ohlc_list(instrument_id, df, period, **kwargs)
+
+
+def fin_read_ohlc_list(instrument_id: str, start_date: int = 0, end_date: int = 99999999, period: str = '1T', **kwargs):
     '''
     获取ohlc数据
     :param instrument_id:合约编码
-    :param range:周期
     :param start_date 开始日期
     :param end_date 结束日期
-    :param base_path 存储路径,为空使用系统默认
-    :param is_return_list 是否返回list格式
+    :param period:周期
+    :param base_path 默认存取目录
     :return:result,msg
     '''
-    return FinClient.instance().market_handle().fin_read_ohlc_list(FinPersistReadParamData(instrument_id=instrument_id, range=range, start_date=start_date, end_date=end_date, base_path=base_path), is_return_list=is_return_list)
+    base_path = '' if 'base_path' not in kwargs.keys()else kwargs.get('base_path')
+    return FinDataClient.instance().findata_handle().fin_read_ohlc_list(FinPersistReadParamData(
+        instrument_id=instrument_id, period=period, start_date=start_date, end_date=end_date, base_path=base_path))
 
 
 def fin_save_tick_list(instrument_id, df, **kwargs):
@@ -382,34 +467,101 @@ def fin_save_tick_list(instrument_id, df, **kwargs):
         instrument_id (str, optional) 合约编码 Defaults  to ''.
         df (DataFrame, optional): 数据集
         包含列
-        ['ExchangeID':str, 'InstrumentID':str, 'ActionDay':str, 'ActionTime':str, 'ActionMSec':int,
-        'LastPrice':float, 'LastVolume':int, 'BidPrice':float, 'BidVolume':int, 'AskPrice':float, 'AskVolume':int,
-        'TotalTurnover':float, 'TotalVolume':int, 'OpenInterest':float, 'PreClosePrice':float,
-        'PreSettlementPrice':float, 'PreOpenInterest':float]
+        "ExchangeID": str, "InstrumentID": str, "TradingDay": str, "ActionDay": str,
+        "ActionTime": str, "ActionMSec": str, "LastPrice": np.float32,
+        "LastVolume": np.int32, "BidPrice": np.float32, "BidVolume": np.int32,
+        "AskPrice": np.float32, "AskVolume": np.int32, "TotalTurnover": np.float64,
+        "TotalVolume": np.int32, "OpenInterest": np.int32
         compress (str, optional):zip xz 压缩方式 Defaults to 'zip'.
         level 压缩等级
         pack 序列化方式 msgpack pickle Defaults to 'msgpack'.
         vacuum 是否直接整理数据文件 Defaults to True.
+        period (str, optional) 周期 Defaults  to 'tick'
+        base_path 默认存取目录
 
     Returns:
         _type_: [bool,str]
     """
-    return FinClient.instance().market_handle().fin_save_tick_list(instrument_id, df, **kwargs)
+    period = 'tick' if 'period' not in kwargs.keys() else kwargs.get('period')
+    return FinDataClient.instance().findata_handle().fin_save_tick_list(instrument_id, df, period, **kwargs)
 
 
-def fin_read_tick_list(instrument_id: str, start_date: int = 0, end_date: int = 99999999, base_path: str = '', is_return_list: bool = False):
+def fin_read_tick_list(instrument_id: str, start_date: int = 0, end_date: int = 99999999, period: str = 'tick', **kwargs):
     '''
     获取basetick数据
     :param instrument_id:合约编码
     :param start_date 起始日期
     :param end_date 结束日期
-    :param base_path 路径
-    :param is_return_list 是否返回list格式
+    :param period:周期
+    :param base_path 默认存取目录
     :return: result,msg
     '''
-    return FinClient.instance().market_handle().fin_read_tick_list(
-        FinPersistReadParamData(table_name=instrument_id, range='BTick', start_date=start_date,
-                                end_date=end_date, base_path=base_path), is_return_list=is_return_list)
+    base_path = '' if 'base_path' not in kwargs.keys()else kwargs.get('base_path')
+    return FinDataClient.instance().findata_handle().fin_read_tick_list(
+        FinPersistReadParamData(instrument_id=instrument_id, period=period, start_date=start_date,
+                                end_date=end_date, base_path=base_path))
+
+
+def fin_read_db_list(instrument_id: str, start_date: int = 0, end_date: int = 99999999, period: str = '', **kwargs):
+    '''
+    获取basetick数据
+    :param instrument_id:合约编码
+    :param start_date 起始日期
+    :param end_date 结束日期
+    :param period:周期
+    :param base_path 默认存取目录
+    :return: result,msg
+    '''
+    base_path = '' if 'base_path' not in kwargs.keys()else kwargs.get('base_path')
+    return FinDataClient.instance().findata_handle().fin_read_db_list(
+        FinPersistReadParamData(instrument_id=instrument_id, period=period, start_date=start_date,
+                                end_date=end_date, base_path=base_path))
+
+
+def fin_delete_list(instrument_id: str, start_date: int, end_date: int, period: str, **kwargs):
+    '''
+    获取数据
+    :param instrument_id:合约编码
+    :param start_date 起始日期
+    :param end_date 结束日期
+    :param period:周期
+    :param base_path 默认存取目录
+    :return: result,msg
+    '''
+    base_path = '' if 'base_path' not in kwargs.keys()else kwargs.get('base_path')
+    return FinDataClient.instance().findata_handle().fin_delete_list(
+        FinPersistDeleteParamData(instrument_id=instrument_id, period=period, start_date=start_date,
+                                  end_date=end_date, base_path=base_path))
+
+
+def fin_read_exc_products(exchange_id: List[str], product_id: List[str]):
+    '''
+    获取品种信息及交易时段
+    :param exchange_id:交易所列表
+    :param product_id:品种列表
+    :return: result,msg,df df类型为DataFrame,其中Times列为dataframe类型
+    '''
+    return FinDataClient.instance().findata_handle().fin_read_exc_products(ReadExcProductParamData(exchange_id=exchange_id, product_id=product_id))
+
+
+def fin_read_instruments(exchange_id: List[str] = [], instrument_id: List[str] = [], unicode: List[str] = [], **kwargs):
+    '''
+    获取品种信息及交易时段
+    :param exchange_id:交易所列表
+    :param instrument_id:合约编码
+    :param unicode:唯一编码
+    :return: result,msg,df df类型为DataFrame
+    '''
+    return FinDataClient.instance().findata_handle().fin_read_instruments(ReadInstrumentParamData(exchange_id=exchange_id, instrument_id=instrument_id, unicode=unicode))
+
+
+def fin_save_instruments(df, **kwargs):
+    '''
+    获取品种信息及交易时段
+    :param df:数据dataframe
+    :return: result,msg
+    '''
+    return FinDataClient.instance().findata_handle().fin_save_instruments(df=df)
 
 
 def set_trade_params(tradenames: str):
@@ -417,17 +569,7 @@ def set_trade_params(tradenames: str):
 
 
 def insert_order(trade_name, exchange_id: str, instrument_id: str, direc: int, price: float, vol: int, open_close_type: int):
-    return FinClient.instance().trade_handle().insert_order(
-        OrderData(
-            exchange_id=exchange_id,
-            instrument_id=instrument_id,
-            price=price,
-            direction=direc,
-            volume=vol,
-            investor_id=trade_name,
-            open_close_type=open_close_type
-        )
-    )
+    return FinClient.instance().trade_handle().insert_order(OrderData(exchange_id=exchange_id, instrument_id=instrument_id, price=price, direction=direc, volume=vol, investor_id=trade_name, open_close_type=open_close_type))
 
 
 def cancel_order_by_data(order: OrderData):
@@ -464,7 +606,13 @@ def read_history_tradeorders(start_date: str, end_date: str):
     )
 
 
-def read_exc_products(exchange_id: str, product_id: str):
+def read_exc_products(exchange_id: List[str], product_id: List[str]):
+    '''
+    获取品种信息及交易时段
+    :param exchange_id:交易所列表
+    :param product_id:品种列表
+    :return: result,msg,df df类型为DataFrame,其中Times列为dataframe类型
+    '''
     return FinClient.instance().trade_handle().read_exc_products(ReadExcProductParamData(exchange_id=exchange_id, product_id=product_id))
 
 
