@@ -3,10 +3,11 @@ from ...packer.market.fin_persist_filed_data_packer import FinPersistFiledDataPa
 
 
 class FinPersistFiledData(IData):
-    def __init__(self, day: int = 0, mark: str = '', buffer: bytes = b''):
+    def __init__(self, day: int = 0, mark: str = '', offset: int = 0, buffer: bytes = b''):
         super().__init__(FinPersistFiledDataPacker(self))
         self._Day: int = day
         self._Mark: str = mark
+        self._Offset: int = offset
         self._Buffer: bytes = buffer
 
     @property
@@ -25,6 +26,14 @@ class FinPersistFiledData(IData):
     def Mark(self, value: str):
         self._Mark = value
 
+    @property
+    def Offset(self):
+        return self._Offset
+
+    @Offset.setter
+    def Offset(self, value: int):
+        self._Offset = value
+
     @property
     def Buffer(self):
         return self._Buffer
