@@ -1,12 +1,13 @@
+from typing import List
 from ...interface import IData
 from ...packer.trade.read_exc_product_param_data_packer import ReadExcProductParamDataPacker
 
 
 class ReadExcProductParamData(IData):
-    def __init__(self, exchange_id: str = '', product_id: str = ''):
+    def __init__(self, exchange_id: List[str] = [], product_id: List[str] = []):
         super().__init__(ReadExcProductParamDataPacker(self))
-        self._ExchangeID: str = exchange_id
-        self._ProductID: str = product_id
+        self._ExchangeID: List[str] = exchange_id.copy()
+        self._ProductID: List[str] = product_id.copy()
         self._DataList = []
 
     @property
@@ -14,7 +15,7 @@ class ReadExcProductParamData(IData):
         return self._ExchangeID
 
     @ExchangeID.setter
-    def ExchangeID(self, value: str):
+    def ExchangeID(self, value: List[str]):
         self._ExchangeID = value
 
     @property
@@ -22,7 +23,7 @@ class ReadExcProductParamData(IData):
         return self._ProductID
 
     @ProductID.setter
-    def ProductID(self, value: str):
+    def ProductID(self, value: List[str]):
         self._ProductID = value
 
     @property
