@@ -5,11 +5,11 @@ from .order_data import OrderData
 
 
 class ReadHistoryOrderParamData(IData):
-    def __init__(self, start_date: str = '', end_date: str = '', data_list: List[OrderData] = []):
+    def __init__(self, start_date: str = '', end_date: str = ''):
         super().__init__(ReadHistoryOrderParamDataPacker(self))
         self._StartDate: str = start_date
         self._EndDate: str = end_date
-        self._DataList: List[OrderData] = data_list
+        self._DataList: List[OrderData] = []
 
     @property
     def StartDate(self):
