@@ -4,6 +4,8 @@ import lzma
 import zlib
 import datetime
 import pickle
+import pandas as pd
+import numpy as np
 
 
 from .req_rsp import ReqRspDict, ReqRsp
@@ -22,7 +24,7 @@ from ..data.market.history_ohlc_param_data import HistoryOHLCParamData
 from ..data.market.fin_persist_filed_data import FinPersistFiledData
 from ..data.market.fin_persist_save_param_data import FinPersistSaveParamData
 from ..data.market.fin_persist_read_param_data import FinPersistReadParamData
-import pandas as pd
+from ..data.market.fin_persist_delete_param_data import FinPersistDeleteParamData
 
 
 class MarketHandle():
@@ -33,17 +35,22 @@ class MarketHandle():
         self.__Listener = None
         self.__ReqRspDict = ReqRspDict()
         self.__Tick_Columns_Types = {"ExchangeID": str, "InstrumentID": str, "TradingDay": str, "ActionDay": str,
-                                     "ActionTime": str, "ActionMSec": int, "LastPrice": float,
-                                     "LastVolume": int, "BidPrice": float, "BidVolume": int,
-                                     "AskPrice": float, "AskVolume": int, "TotalTurnover": float,
-                                     "TotalVolume": int, "OpenInterest": int, "PreClosePrice": float,
-                                     "PreSettlementPrice": float, "PreOpenInterest": int}
+                                     "ActionTime": str, "ActionMSec": str, "LastPrice": np.float32,
+                                     "LastVolume": np.int32, "BidPrice": np.float32, "BidVolume": np.int32,
+                                     "AskPrice": np.float32, "AskVolume": np.int32, "TotalTurnover": np.float64,
+                                     "TotalVolume": np.int32, "OpenInterest": np.int32}
         self.__OHLC_Columns_Types = {
-            "ExchangeID": str, "InstrumentID": str, "TradingDay": str, "ActionDay": str, "ActionTime": str, "ActionMTS": int,
-            "Period": int, "OpenPrice": float, "HighestPrice": float, "LowestPrice": float,
-            "ClosePrice": float, "CloseVolume": int, "CloseBidPrice": float, "CloseAskPrice": float, "CloseBidVolume": int, "CloseAskVolume": int,
-            "TotalTurnover": float, "TotalVolume": int, "OpenInterest": int,
-            "PreClosePrice": float, "PreSettlementPrice": float, "PreOpenInterest": int}
+            "ExchangeID": str, "InstrumentID": str, "TradingDay": str, "ActionDay": str, "ActionTime": str,
+            "Period": np.int32, "OpenPrice": np.float32, "HighestPrice": np.float32, "LowestPrice": np.float32,
+            "ClosePrice": np.float32, "CloseVolume": np.int32, "CloseBidPrice": np.float32,
+            "CloseAskPrice": np.float32, "CloseBidVolume": np.int32, "CloseAskVolume": np.int32,
+            "TotalTurnover": np.float64, "TotalVolume": np.int32, "OpenInterest": np.int32}
+
+        self.__Day_Columns_Types = {
+            "ExchangeID": str, "InstrumentID": str, "TradingDay": str,
+            "OpenPrice": np.float32, "HighestPrice": np.float32, "LowestPrice": np.float32, "ClosePrice": np.float32,
+            "UpperLimitPrice": np.float32, "LowerLimitPrice": np.float32, "SettlementPrice": np.float32,
+            "TotalTurnover": np.float64, "TotalVolume": np.int32, "OpenInterest": np.int32}
 
     def set_callback(self, **kwargs):
         if kwargs is None:
@@ -60,6 +67,9 @@ class MarketHandle():
     def get_tick_column_types(self):
         return self.__Tick_Columns_Types
 
+    def get_day_column_types(self):
+        return self.__Day_Columns_Types
+
     def set_market_params(self, params: MarketParamData) -> Tuple[bool, str]:
         return self.__wait_send_msg(int(MsgID.MSGID_Market_SetParams.value), params)
 
@@ -97,22 +107,52 @@ class MarketHandle():
         self.__ReqRspDict.remove(key)
         return ret
 
-    def fin_save_ohlc_list(self, instrument_id: str, range: str, df, **kwargs) -> Tuple[bool, str]:
+    def fin_save_day_list(self, instrument_id: str, df, period: str, **kwargs) -> Tuple[bool, str]:
+        if len(period) == 0:
+            period = "day"
+        return self.__fin_save_list(int(MsgID.MSGID_Market_FinSaveDayList.value), self.__Day_Columns_Types.keys(),
+                                    instrument_id, df, period, "TradingDay", **kwargs)
+
+    def fin_read_day_list(self, params: FinPersistReadParamData) -> Tuple[bool, str, pd.DataFrame]:
+        return self.__fin_read_list(int(MsgID.MSGID_Market_FinReadDayList.value), "day",
+                                    self.__Day_Columns_Types.keys(), params)
+
+    def fin_save_ohlc_list(self, instrument_id: str, df, period: str, **kwargs) -> Tuple[bool, str]:
+        return self.__fin_save_list(int(MsgID.MSGID_Market_FinSaveOHLCList.value), self.__OHLC_Columns_Types.keys(),
+                                    instrument_id, df, period, "ActionDay", **kwargs)
+
+    def fin_read_ohlc_list(self, params: FinPersistReadParamData) -> Tuple[bool, str, pd.DataFrame]:
+        return self.__fin_read_list(int(MsgID.MSGID_Market_FinReadOHLCList.value), "ohlc",
+                                    self.__OHLC_Columns_Types.keys(), params)
+
+    def fin_save_tick_list(self, instrument_id, df, period: str, **kwargs) -> Tuple[bool, str]:
+        if len(period) == 0:
+            period = "tick"
+        return self.__fin_save_list(int(MsgID.MSGID_Market_FinSaveTickList.value), self.__Tick_Columns_Types.keys(),
+                                    instrument_id, df, period, "ActionDay", **kwargs)
+
+    def fin_read_tick_list(self, params: FinPersistReadParamData) -> Tuple[bool, str, pd.DataFrame]:
+        return self.__fin_read_list(int(MsgID.MSGID_Market_FinReadTickList.value), "tick",
+                                    self.__Tick_Columns_Types.keys(), params)
+
+    def fin_delete_list(self, params: FinPersistDeleteParamData) -> Tuple[bool, str]:
+        return self.__wait_send_msg(int(MsgID.MSGID_Market_FinDeleteList.value), params)
+
+    def __fin_save_list(self, mid: int, col_keys, instrument_id, df, period: str, groupby_key: str, **kwargs) -> Tuple[bool, str]:
         if not isinstance(df, pd.DataFrame):
-            return [False, "df 数据类型格式不是 DataFrame", {}]
+            return [False, "df 数据类型格式不是 DataFrame"]
 
-        if df.columns.to_list() != list(self.__OHLC_Columns_Types.keys()):
-            return [False, "df 数据列名称不匹配,当前:%s 应为:%s" % (df.columns.to_list(), list(self.__OHLC_Columns_Types.keys()))]
+        if df.columns.to_list() != list(col_keys):
+            return [False, "df 数据列名称不匹配,当前:%s 应为:%s" % (df.columns.to_list(), col_keys)]
 
-        b, m, params = self.__create_fin_persists_save_param_data(instrument_id, range, df, kwargs=kwargs)
+        b, m, params = self.__create_fin_persists_save_param_data(instrument_id, df, period, groupby_key, **kwargs)
         if b == False:
             return [b, m]
 
-        return self.__wait_send_msg(int(MsgID.MSGID_Market_FinSaveOHLCList.value), params)
+        return self.__wait_send_msg(int(mid), params)
 
-    def fin_read_ohlc_list(self, params: FinPersistReadParamData, is_return_list: bool = False) -> Tuple[bool, str, pd.DataFrame]:
+    def __fin_read_list(self, mid: int, period_name: str, col_keys, params: FinPersistReadParamData) -> Tuple[bool, str, pd.DataFrame]:
         self.__ReqID = self.__ReqID + 1
-        mid = int(MsgID.MSGID_Market_FinReadOHLCList.value)
         msg = MessageData(mid=mid, request_id=self.__ReqID)
         if params is not None:
             msg.UData = params.pack()
@@ -126,53 +166,9 @@ class MarketHandle():
         rsp = req_rsp.wait_last_rsp(60)
         if rsp is None:
             self.__ReqRspDict.remove(key)
-            return [False, '获取历史OHLC数据超时', None]
+            return [False, ('获取%s数据超时' % period_name), None]
 
-        ret = [True, "", None]
-        if is_return_list is True:
-            ret = [rsp.RspSuccess, rsp.RspMsg, self.__unpack_ohlc_list_v2(req_rsp)]
-        else:
-            ret = [rsp.RspSuccess, rsp.RspMsg, self.__unpack_fin_persist_read_param_data_to_df(req_rsp, list(self.__OHLC_Columns_Types.keys()))]
-
-        self.__ReqRspDict.remove(key)
-        return ret
-
-    def fin_save_tick_list(self, instrument_id, df, **kwargs) -> Tuple[bool, str]:
-        if not isinstance(df, pd.DataFrame):
-            return [False, "df 数据类型格式不是 DataFrame", {}]
-
-        if df.columns.to_list() != list(self.__Tick_Columns_Types.keys()):
-            return [False, "df 数据列名称不匹配,当前:%s 应为:%s" % (df.columns.to_list(), self.__Tick_Columns_Types.keys())]
-
-        b, m, params = self.__create_fin_persists_save_param_data(instrument_id, "Tick", df, **kwargs)
-        if b == False:
-            return [b, m]
-
-        return self.__wait_send_msg(int(MsgID.MSGID_Market_FinSaveTickList.value), params)
-
-    def fin_read_tick_list(self, params: FinPersistReadParamData, is_return_list: bool = False) -> Tuple[bool, str, pd.DataFrame]:
-        self.__ReqID = self.__ReqID + 1
-        mid = int(MsgID.MSGID_Market_FinReadTickList.value)
-        msg = MessageData(mid=mid, request_id=self.__ReqID)
-        if params is not None:
-            msg.UData = params.pack()
-
-        key = '%s_%s' % (mid, self.__ReqID)
-        req_rsp = self.__ReqRspDict.new_reqrsp(key, msg)
-        if self.__TSocket.send_message(msg) is False:
-            self.__ReqRspDict.remove(key)
-            return [False, '发送命令失败', None]
-
-        rsp = req_rsp.wait_last_rsp(60)
-        if rsp is None:
-            self.__ReqRspDict.remove(key)
-            return [False, '获取历史basetick数据超时', None]
-
-        ret = [True, "", None]
-        if is_return_list is True:
-            ret = [rsp.RspSuccess, rsp.RspMsg, self.__unpack_tick_list(req_rsp)]
-        else:
-            ret = [rsp.RspSuccess, rsp.RspMsg, self.__unpack_fin_persist_read_param_data_to_df(req_rsp, list(self.__Tick_Columns_Types.keys()))]
+        ret = [rsp.RspSuccess, rsp.RspMsg, self.__unpack_fin_persist_read_param_data_to_df(req_rsp, list(col_keys))]
 
         self.__ReqRspDict.remove(key)
         return ret
@@ -213,32 +209,6 @@ class MarketHandle():
                     ohlcs.append(o)
         return ohlcs
 
-    def __unpack_ohlc_list_v2(self, reqrsp: ReqRsp):
-        tempbytes = self.__unpack_decompress_buffers(reqrsp)
-        ohlcs = list()
-        for b in tempbytes:
-            if len(b) <= 0:
-                continue
-            ticklist = msgpack.unpackb(b)
-            for bt in ticklist:
-                o = OHLCData()
-                o.tuple_to_obj(bt)
-                ohlcs.append(o)
-        return ohlcs
-
-    def __unpack_tick_list(self, reqrsp: ReqRsp):
-        tempbytes = self.__unpack_decompress_buffers(reqrsp)
-        ticks = list()
-        for b in tempbytes:
-            if len(b) <= 0:
-                continue
-            ticklist = msgpack.unpackb(b)
-            for bt in ticklist:
-                o = TickData()
-                o.tuple_to_obj(bt)
-                ticks.append(o)
-        return ticks
-
     def __unpack_ohlc_dataframe(self, reqrsp: ReqRsp, rspparams):
         '''暂时保留，兼容旧接口'''
         dfrtn = pd.DataFrame()
@@ -259,7 +229,7 @@ class MarketHandle():
         olist = self.__unpack_decompress_buffers(reqrsp, columns)
         if len(olist) == 0:
             return pd.DataFrame(columns=columns)
-        return pd.concat(olist)
+        return pd.concat(olist, ignore_index=True)
 
     def __unpack_stream_buffer(self, buffer, columns):
         o_list = []
@@ -304,21 +274,25 @@ class MarketHandle():
 
         return dflist
 
-    def __create_fin_persists_save_param_data(self, instrument_id: str, range: str, df, **kwargs):
+    def __create_fin_persists_save_param_data(self, instrument_id: str, df, period: str, groupby_key: str, **kwargs):
         if not isinstance(df, pd.DataFrame):
             return [False, "df 数据类型格式不是 DataFrame", {}]
+        if len(period) == 0:
+            return [False, "period不能为空"]
 
         compress = 'zip' if 'compress' not in kwargs.keys() else kwargs.get('compress')
         level = -1 if 'level' not in kwargs.keys() else kwargs.get('level')
         pack = 'msgpack' if 'pack' not in kwargs.keys() else kwargs.get('pack')
         vacuum = True if 'vacuum' not in kwargs.keys() else kwargs.get('vacuum')
+        base_path = '' if 'base_path' not in kwargs.keys()else kwargs.get('base_path')
 
         params: FinPersistSaveParamData = FinPersistSaveParamData()
         params.Append = False
-        params.Range = range
-        params.TableName = instrument_id
+        params.Period = period
+        params.InstrumentID = instrument_id
         params.Vacuum = bool(vacuum)
-        groups = df.groupby('ActionDay')
+        params.BasePath = base_path
+        groups = df.groupby(groupby_key)
         buffer_sz = 0
         for day, day_list in groups:
             filed = FinPersistFiledData()
