@@ -6,7 +6,7 @@ class ReadExcProductParamDataPacker(IPacker):
         super().__init__(obj)
 
     def obj_to_tuple(self):
-        return [str(self._obj.ExchangeID), str(self._obj.ProductID), list(self._obj.DataList)]
+        return [list(self._obj.ExchangeID), list(self._obj.ProductID), list(self._obj.DataList)]
 
     def tuple_to_obj(self, t):
         if len(t) >= 3:
